@@ -19,10 +19,11 @@
  * WHETHER IN AN ACTION IN CONTRACT, TORT OR NEGLIGENCE, ARISING OUT OF OR IN
  * CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  * 
- * $Id: audispatch.c 236 2007-03-18 06:56:36Z jon $
+ * $Id$
  * $NCDId: @(#)audispatch.c,v 1.13 1996/05/07 20:12:46 greg Exp $
  */
 
+#include <unistd.h>
 #include        "release.h"
 #include        "misc.h"
 #include        "dixstruct.h"
@@ -51,6 +52,8 @@ extern RESTYPE auFlowType, auComponentType;
 extern FlowPtr auClockedFlows, auUnclockedFlows;
 extern ComponentPtr auBuckets, auDevices;
 
+extern void _AuUnBlockAudio(AuBlock _x);
+
 static auConnSetupPrefix auSetupPrefix;
 auConnSetup auSetup;
 
