@@ -29,6 +29,7 @@
 #include <audio/audio.h>
 #include <audio/Aproto.h>
 #include "au.h"
+#include "aulog.h"
 
 #include "nasconf.h"
 
@@ -39,6 +40,7 @@ AuUint8 *auPhysicalOutputBuffers;
 extern AuBool AuChangeElementState();
 extern void AuRequestElementNotifyEvent(), AuRequestMonitorNotifyEvent(),
 AuProcessClockedFlows();
+extern void _AuUnBlockAudio(AuBlock _x);
 
 static AuUint32 rc_1(), rc_2(), rc_4(), rc_n(), rcNull(),
 rcm_1(), rcm_2(), rcm_n();
