@@ -48,11 +48,12 @@ SOFTWARE.
 ******************************************************************/
 
 /*
- * $Id: main.c 227 2006-09-01 05:57:17Z jon $
+ * $Id$
  */
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <unistd.h>
 #include <audio/audio.h>
 #include <audio/Aproto.h>
 #include "NasConfig.h"
@@ -64,19 +65,25 @@ SOFTWARE.
 #include "globals.h"
 #include "nasconf.h"
 #include "release.h"
+#include "aulog.h"
+
+#include "gram.h"
 
 extern void OsInit(void), InitClient(), ResetWellKnownSockets(),
 Dispatch(), FreeAllResources();
 extern int AuInitSetupReply();
 extern void AuInitProcVectors(void);
 extern Bool InitClientResources();
+extern void osBecomeDaemon(void);
+extern void osBecomeOrphan(void);
+
 
 static char *AuServerName(void);
 
 extern char *display;
 
 static int restart = 0;
-FILE *yyin;                     /* for the config parser */
+extern FILE *yyin;                     /* for the config parser */
 
 void
 NotImplemented()
@@ -153,7 +160,7 @@ main(int argc, char *argv[])
 
     /* And cd to / so we don't hold anything up; core files will also
        go there. */
-    chdir("/");
+    int dummy = chdir("/");
 
     while (1) {
         serverGeneration++;
