@@ -30,7 +30,7 @@ from the X Consortium.
 /* $XFree86: xc/programs/xfs/os/daemon.c,v 1.10 2002/06/03 22:16:17 dawes Exp $ */
 
 /* Borrowed from X11 by JET 7/7/2002
- * $Id: daemon.c 225 2006-08-30 00:08:16Z jon $ 
+ * $Id$ 
  */
 
 
@@ -113,7 +113,7 @@ osBecomeOrphan(void)
 void
 osBecomeDaemon(void)
 {
-    register int i;
+    int i;
 
     /*
      * Close standard file descriptors and get rid of controlling tty
